@@ -50,7 +50,7 @@ class PythonBuildTask(TaskExtensionPoint):
         python_lib = os.path.join(
             args.install_base, self._get_python_lib(args))
         os.makedirs(python_lib, exist_ok=True)
-        # and being in the  PYTHONPATH
+        # and being in the PYTHONPATH
         env = dict(env)
         env['PYTHONPATH'] = python_lib + os.pathsep + \
             env.get('PYTHONPATH', '')
@@ -93,7 +93,7 @@ class PythonBuildTask(TaskExtensionPoint):
                 '--build-directory', os.path.join(args.build_base, 'build'),
                 '--no-deps',
             ]
-            if setup_py_data.get('data_files', []):
+            if setup_py_data.get('data_files'):
                 cmd += ['install_data', '--install-dir', args.install_base]
             self._append_install_layout(args, cmd)
             rc = await check_call(
@@ -105,9 +105,15 @@ class PythonBuildTask(TaskExtensionPoint):
             # to maintain the desired order
             if additional_hooks is None:
                 additional_hooks = []
+            base_path = args.build_base
+            # if the Python packages are in a subdirectory
+            # that needs to be appended to the build directory
+            package_dir = setup_py_data.get('package_dir') or {}
+            if '' in package_dir:
+                base_path = os.path.join(base_path, package_dir[''])
             additional_hooks += create_environment_hook(
-                'pythonpath_develop', Path(args.build_base), pkg.name,
-                'PYTHONPATH', args.build_base, mode='prepend')
+                'pythonpath_develop', Path(base_path), pkg.name, 'PYTHONPATH',
+                base_path, mode='prepend')
 
         hooks = create_environment_hooks(args.install_base, pkg.name)
         create_environment_scripts(
@@ -138,7 +144,7 @@ class PythonBuildTask(TaskExtensionPoint):
         with open(install_log, 'r') as h:
             lines = [l.rstrip() for l in h.readlines()]
 
-        packages = setup_py_data.get('packages', [])
+        packages = setup_py_data.get('packages') or []
         for module_name in packages:
             if module_name in sys.modules:
                 logger.warning(
@@ -181,8 +187,8 @@ class PythonBuildTask(TaskExtensionPoint):
         if os.path.exists(os.path.join(args.path, 'setup.cfg')):
             items.append('setup.cfg')
         # add all first level packages
-        package_dir = setup_py_data.get('package_dir', {})
-        for package in setup_py_data.get('packages', []):
+        package_dir = setup_py_data.get('package_dir') or {}
+        for package in setup_py_data.get('packages') or []:
             if '.' in package:
                 continue
             if package in package_dir:
@@ -204,7 +210,7 @@ class PythonBuildTask(TaskExtensionPoint):
                         .format_map(locals()))
             items += py_modules_list
         data_files = get_data_files_mapping(
-            setup_py_data.get('data_files', []))
+            setup_py_data.get('data_files') or [])
         for source in data_files.keys():
             # work around data files incorrectly defined as not relative
             if os.path.isabs(source):
